==> aliyun-python-sdk-dbfs-1.0.2.tar.gz: aliyun-python-sdk-dbfs-1.0.2/aliyunsdkdbfs/request/v20200418/AttachDbfsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdbfs.endpoint import endpoint_data

class AttachDbfsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'AttachDbfs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ECSInstanceId(self):
		return self.get_query_params().get('ECSInstanceId')

	def set_ECSInstanceId(self,ECSInstanceId):
		self.add_query_param('ECSInstanceId',ECSInstanceId)

	def get_FsId(self):
		return self.get_query_params().get('FsId')

	def set_FsId(self,FsId):
		self.add_query_param('FsId',FsId)

==> aliyun-python-sdk-dbfs-1.9.0b0.tar.gz: aliyun-python-sdk-dbfs-1.9.0b0/aliyunsdkdbfs/request/v20200418/AttachDbfsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdbfs.endpoint import endpoint_data

class AttachDbfsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'DBFS', '2020-04-18', 'AttachDbfs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ECSInstanceId(self):
		return self.get_query_params().get('ECSInstanceId')

	def set_ECSInstanceId(self,ECSInstanceId):
		self.add_query_param('ECSInstanceId',ECSInstanceId)

	def get_ServerUrl(self):
		return self.get_query_params().get('ServerUrl')

	def set_ServerUrl(self,ServerUrl):
		self.add_query_param('ServerUrl',ServerUrl)

	def get_FsId(self):
		return self.get_query_params().get('FsId')

	def set_FsId(self,FsId):
		self.add_query_param('FsId',FsId)
